@@ -352,11 +352,14 @@ class PFileDialogBase(PAppDialogBase):
     def _ext_str_from_list(self, ext_list):
         return self.ext_sep.join("*.{}".format(ext) for ext in ext_list)
     
+    def _translate_filter_listitem(self, caption, ext_list):
+        return self._translate_filter_item(caption, self._ext_str_from_list(ext_list))
+    
     filter_sep = None
     
     def _translate_filter(self, filter):
         return self.filter_sep.join(
-            self._translate_filter_item(caption, self._ext_str_from_list(ext_list))
+            self._translate_filter_listitem(caption, ext_list)
             for caption, ext_list in filter
         )
     
@@ -371,10 +374,10 @@ class PFileDialogBase(PAppDialogBase):
         raise NotImplementedError
     
     def open_filename(self, path, filter, selected_filter):
-        return self._open_filename(path, self._translate_filter(filter), self._translate_filter_item(*selected_filter))
+        return self._open_filename(path, self._translate_filter(filter), self._translate_filter_listitem(*selected_filter))
     
     def save_filename(self, path, filter, selected_filter):
-        return self._save_filename(path, self._translate_filter(filter), self._translate_filter_item(*selected_filter))
+        return self._save_filename(path, self._translate_filter(filter), self._translate_filter_listitem(*selected_filter))
 
 
 class PAboutDialogBase(PAppDialogBase):
