@@ -22,7 +22,7 @@ class PDialog(qt.QDialog, PQtWidgetBase, PDialogBase,
     
     widget_class = qt.QDialog
     
-    def __init__(self, manager, parent, caption, client=None,
+    def __init__(self, manager, parent, caption, client,
                  accept_buttons=('ok', 'yes'), reject_buttons=('cancel', 'no')):
         
         qt.QDialog.__init__(self, parent)
