@@ -30,7 +30,7 @@ class PButtonGroupBase(PButtonGroupMixin, PPanel,
     group = None
     
     def __init__(self, manager, parent, align, layout, items=None, starting_index=None,
-                 style=PANEL_NONE, margin=None, spacing=None):
+                 style=PANEL_PLAIN, margin=None, spacing=None):
         
         PPanel.__init__(self, manager, parent, align, layout,
                         style=style, margin=margin, spacing=spacing)
