@@ -75,7 +75,7 @@ class PQtStatusPanel(PPanel):
     
     label = None
     
-    def __init__(self, manager, parent, caption="", style=PANEL_NONE):
+    def __init__(self, manager, parent, caption="", style=PANEL_PLAIN):
         PPanel.__init__(self, manager, parent, ALIGN_RIGHT, LAYOUT_HORIZONTAL,
                         style=style, margin=PANEL_MARGIN, spacing=PANEL_SPACING)
         self.label = PTextLabel(manager, self, caption)
