@@ -115,13 +115,7 @@ class PTable(PWxSequenceWidget, wx.grid.Grid, PTableBase):
         if self._editing_cell:
             self._pending_select = (new_row, new_col)
         else:
-            selected_fields = (
-                ('CurrentRow', new_row),
-                ('CurrentCol', new_col),
-                ('PreviousRow', self.current_row()),
-                ('PreviousCol', self.current_col()),
-            )
-            self.forward_event(SIGNAL_CELLSELECTED, event, selected_fields)
+            self.forward_event(SIGNAL_CELLSELECTED, event, new_row, new_col, self.current_row(), self.current_col())
     
     def OnCellEdit(self, event):
         self._editing_cell = True
@@ -134,11 +128,7 @@ class PTable(PWxSequenceWidget, wx.grid.Grid, PTableBase):
         assert self._editing_cell
         self._row = event.GetRow()
         self._col = event.GetCol()
-        changed_fields = (
-            ('Row', self._row),
-            ('Col', self._col),
-        )
-        self.forward_event(SIGNAL_CELLCHANGED, event, changed_fields)
+        self.forward_event(SIGNAL_CELLCHANGED, event, self._row, self._col)
     
     def wrap_target(self, signal, target):
         # Ugly hack so current_row and current_col return the correct values
@@ -162,15 +152,9 @@ class PTable(PWxSequenceWidget, wx.grid.Grid, PTableBase):
         if self._pending_select:
             new_row, new_col = self._pending_select
             self._pending_select = None
-            selected_fields = (
-                ('CurrentRow', new_row),
-                ('CurrentCol', new_col),
-                # We cheat here by using the cell changed row/col as the previous row/col
-                # for the cell select event (it would be really nice if wx would do this for us)
-                ('PreviousRow', event.GetRow()),
-                ('PreviousCol', event.GetCol()),
-            )
-            self.forward_event(SIGNAL_CELLSELECTED, event, selected_fields)
+            # We cheat here by using the cell changed row/col as the previous row/col
+            # for the cell select event (it would be really nice if wx would do this for us)
+            self.forward_event(SIGNAL_CELLSELECTED, event, new_row, new_col, event.GetRow(), event.GetCol())
     
     def OnSizeEvent(self, event):
         self.StretchColumns()
